# TODO: Fill out this file with information about your package

# HINT: Go back to the object-oriented programming lesson "Putting Code on PyPi" and "Exercise: Upload to PyPi"

# HINT: Here is an example of a setup.py file
# https://packaging.python.org/tutorials/packaging-projects/
from setuptools import setup

setup(name='name_matcher',
      author='Ammar Raza',
      version='0.1',
      descrption='Match fields and provide match percentage',
      packages=['name_matcher'],
      author_email='ammar_reza@hotmail.com',
      zip_safe=False)